@@ -10,6 +10,8 @@ pub enum CompilationError {
     MixedOperators,
     #[error("Invalid step")]
     InvalidStep,
+    #[error("Undefined schema definition name: {0}")]
+    UndefinedSchemaDefinitionName(String),
     #[error(transparent)]
     RegexError(#[from] regex::Error),
 }
