@@ -1,6 +1,6 @@
+pub mod context;
 pub mod error;
 pub mod parse;
-pub mod path;
 pub mod predicate;
 
 pub mod schemas {
@@ -9,6 +9,9 @@ pub mod schemas {
 
 pub mod step;
 
+pub use context::Context;
+pub use context::Env;
+
 pub use error::CompilationError;
 
 pub use parse::parse_selector;
